************************************************************************************************
*The Stata code accompanying the paper "A Rational Theory of Mutual Funds' Attention Allocation*
************************************************************************************************

*********************************************************************************************************************************************
*The file has a structure of a readme file. It gives reference to all auxiliary codes that are used to generate some of the input data files*
*********************************************************************************************************************************************

*********************************************************************************
*Table 1: Panel A (time-series evidence on volatility of micro and macro shocks)*
*********************************************************************************

clear all

*Load the aggregate and idiosyncratic risk measures. These are calculate in a Matlab code (rsqstocks_new.m)
use "/Users/mkacperc/Stijn/Revision/Data/stockrsqbetasigeps.dta"

*Merging data with factors (monthly data directly obtained from WRDS: mktrf, smb, hml, umd, rf)
sort time
merge time using "/Users/mkacperc/Stijn/Revision/Data/factors_stocks.dta",nokeep
drop _merge

*Generating excess returns
replace ret=ret-rf

*Winsorizing the risk measures
winsor sigepsstock,gen(Wsigepsstock) p(0.005)
winsor betasqvolstock,gen(Wbetasqvolstock) p(0.005)

*Generating average risk measures
sort time
by time: egen avgsigepsagg=mean(Wsigepsstock)
by time: egen avgbetasqvolagg=mean(Wbetasqvolstock)

*Restricting the data to the period 1980-2005 (consistent with the mutual fund data)
keep if yearm>198003 & yearm<=200512

keep yearm time recession2 avgsigepsagg avgbetasqvolagg mktrf smb hml umd

duplicates drop

*Generating aggregate risk measure
gen avgsigmktagg=sqrt(avgbetasqvolagg)*100

*Expressing risk measures in percentage terms
replace avgsigepsagg=avgsigepsagg*100
replace avgbetasqvolagg=avgbetasqvolagg*100

*Generating the ratio of risk measures
gen avgratio=avgsigmktagg/avgsigepsagg

tsset time

*Table 1: Panel A (time-series regression)
newey avgsigmktagg recession2,lag(4)
outreg2 using "/Users/mkacperc/Stijn/Revision/ECTA/table1a.xls", replace se bdec(3)
newey avgsigmktagg recession2 mktrf smb hml umd,lag(4)
outreg2 using "/Users/mkacperc/Stijn/Revision/ECTA/table1a.xls", append se bdec(3)
newey avgsigepsagg recession2,lag(4)
outreg2 using "/Users/mkacperc/Stijn/Revision/ECTA/table1a.xls", append se bdec(3)
newey avgsigepsagg recession2 mktrf smb hml umd,lag(4)
outreg2 using "/Users/mkacperc/Stijn/Revision/ECTA/table1a.xls", append se bdec(3)
newey avgratio recession2,lag(4)
outreg2 using "/Users/mkacperc/Stijn/Revision/ECTA/table1a.xls", append se bdec(3)
newey avgratio recession2 mktrf smb hml umd,lag(4)
outreg2 using "/Users/mkacperc/Stijn/Revision/ECTA/table1a.xls", append se bdec(3)


*************************************************************************************
*Table 1: Panel B (cross-sectional evidence on volatility of micro and macro shocks)*
*************************************************************************************

clear all

*Load the aggregate and idiosyncratic risk measures. These are calculate in a Matlab code (rsqstocks_new.m)
use "/Users/mkacperc/Stijn/Revision/Data/stockrsqbetasigeps.dta"

drop sprtrn stockalphacar stockalphacapm stockalphaff capmstock ffstock carstock id stockbeta stockrsquared lnsize exretstock

*Generating year variable for matching purpose
gen year=int(yearm/100)

*Merging corporate controls for regressions (from Compustat: permno, year, bkvpls, blev)
sort permno year
merge permno year using "/Users/mkacperc/Stijn/Revision/Data/corpcontrols.dta",nokeep
drop _merge

*Merging exchange data (available from CRSP on WRDS: permno yearm, nasd)
sort permno yearm
merge permno yearm using "/Users/mkacperc/Stijn/Revision/Data/nasdaq.dta",nokeep
drop _merge

*Generating market equity
gen size=prc*shrout
gen lnsize=ln(size)

*Generating book to markewt and momentum variables
tsset permno time
gen bktmk=bkvlps/L.prc
gen mom=(1+L.ret)*(1+L2.ret)*(1+L3.ret)*(1+L4.ret)*(1+L5.ret)*(1+L6.ret)*(1+L7.ret)*(1+L8.ret)*(1+L9.ret)*(1+L10.ret)*(1+L11.ret)*(1+L12.ret)-1

*Winsorizing the main variables
winsor sigepsstock,gen(Wsigepsstock) p(0.005)
winsor betasqvolstock,gen(Wbetasqvolstock) p(0.005)
winsor bktmk,gen(Wbktmk) p(0.025)
winsor blev,gen(Wblev) p(0.005)
winsor mom,gen(Wmom) p(0.005)

*Restricting the data to the period 1980-2005 (consistent with the mutual fund data)
keep if yearm>198003 & yearm<=200512

*Demeaning the series for interpretation purpose
gen sum=lnsize+Wbktmk+Wmom+Wblev+nasd+Wsigepsstock+recession2

egen meansize=mean(lnsize) if sum~=.
egen meanbktmk=mean(Wbktmk) if sum~=.
egen meanmom=mean(Wmom) if sum~=.
egen meanlev=mean(Wblev) if sum~=.
egen meannasd=mean(nasd) if sum~=.

replace lnsize=lnsize-meansize
replace Wbktmk=Wbktmk-meanbktmk
replace Wmom=Wmom-meanmom
replace Wblev=Wblev-meanlev
replace nasd=nasd-meannasd

*Generating standard deviation of aggregate risk
gen Wsigmktstock=sqrt(Wbetasqvolstock)

*Expressing risk measures in percentage terms
replace Wsigepsstock=Wsigepsstock*100
replace Wsigmktstock=Wsigmktstock*100

*Generating the ratio of risk measures
gen ratio=Wsigmktstock/Wsigepsstock

*Table 1: Panel B (cross-sectional regression)
reg Wsigmktstock recession2 if L.lnsize~=. & L.Wbktmk~=. & L.Wmom~=. & L.Wblev~=. & L.nasd~=., cluster(time)
outreg2 using "/Users/mkacperc/Stijn/Revision/ECTA/table1b.xls", replace se bdec(3)
reg Wsigmktstock recession2 L.lnsize L.Wbktmk L.Wmom L.Wblev L.nasd, cluster(time)
outreg2 using "/Users/mkacperc/Stijn/Revision/ECTA/table1b.xls", append se bdec(3)
reg Wsigepsstock recession2 if L.lnsize~=. & L.Wbktmk~=. & L.Wmom~=. & L.Wblev~=. & L.nasd~=., cluster(time)
outreg2 using "/Users/mkacperc/Stijn/Revision/ECTA/table1b.xls", append se bdec(3)
reg Wsigepsstock recession2 L.lnsize L.Wbktmk L.Wmom L.Wblev L.nasd, cluster(time)
outreg2 using "/Users/mkacperc/Stijn/Revision/ECTA/table1b.xls", append se bdec(3)
reg ratio recession2 if L.lnsize~=. & L.Wbktmk~=. & L.Wmom~=. & L.Wblev~=. & L.nasd~=., cluster(time)
outreg2 using "/Users/mkacperc/Stijn/Revision/ECTA/table1b.xls", append se bdec(3)
reg ratio recession2 L.lnsize L.Wbktmk L.Wmom L.Wblev L.nasd, cluster(time)
outreg2 using "/Users/mkacperc/Stijn/Revision/ECTA/table1b.xls", append se bdec(3)




reg RAI recession2 voldum32 logage2 log_assets2 expenses2 Wturn2 Wflow2 load2,cluster(date)
outreg2 using \Stijn\Revision\RES\table2_contvol.xls, replace se bdec(3) noaster
reg RAI recession2 F6realvol logage2 log_assets2 expenses2 Wturn2 Wflow2 load2,cluster(date)
outreg2 using \Stijn\Revision\RES\table2_contvol.xls, append se bdec(3) noaster
reg RAI recession2 F6realvol realvolsq logage2 log_assets2 expenses2 Wturn2 Wflow2 load2,cluster(date)
outreg2 using \Stijn\Revision\RES\table2_contvol.xls, append se bdec(3) noaster
reg RSI recession2 voldum32 logage1 log_assets1 expenses1 Wturn1 Wflow1 load1, cluster(date)
outreg2 using \Stijn\Revision\RES\table2_contvol.xls, append se bdec(3) noaster
reg RSI recession2 F6realvol logage1 log_assets1 expenses1 Wturn1 Wflow1 load1, cluster(date)
outreg2 using \Stijn\Revision\RES\table2_contvol.xls, append se bdec(3) noaster
reg RSI recession2 F6realvol realvolsq logage1 log_assets1 expenses1 Wturn1 Wflow1 load1, cluster(date)
outreg2 using \Stijn\Revision\RES\table2_contvol.xls, append se bdec(3) noaster

*******************************************
*Table 2 (Ftiming and Fpicking regressions*
*******************************************

clear all

*Loading mutual fund data from CRSP (icdi, fundno, date, yearm, expenses, turnover, tnam, date_inc, load, retm)
use "/Users/mkacperc/Stijn/Revision/Data/returns2.dta"

*Merging recession data (Monthly data based on NBER recession dates from www.nber.org: date, recession2)
sort date
merge date using "/Users/mkacperc/Stijn/Revision/Data/recession_data.dta",nokeep
tab _merge
drop _merge

*Merging volatility data
sort yearm
merge yearm using "/Users/mkacperc/Stijn/Revision/Data/volcf.dta",nokeep
tab _merge
drop _merge

*Merging Ftiming data (this comes from the output in Matlab file covarindeps.m)
sort fundno yearm
merge fundno yearm using "/Users/mkacperc/Stijn/Revision/Data/covindeps.dta",nokeep
tab _merge
drop _merge

*Merging Fpicking data (this comes from the output in Matlab file covarsue31.m)
sort fundno yearm
merge fundno yearm using "/Users/mkacperc/Stijn/Revision/Data/rsi_new.dta",nokeep
tab _merge
drop _merge

*Merging price of risk data (yearm, defaultspread=yield on BBB and AAA)
sort yearm
merge yearm using "/Users/mkacperc/Stijn/Revision/Data/dew_becker.dta",nokeep
tab _merge
drop _merge

*Calculating flows
tsset icdi time
flow=(tnam-L.tnam*(1+retm))/L.tnam

*Winsorizing fund controls
winsor flow,gen(Wflow) p(0.005)
winsor turnover,gen(Wturn) p(0.005)

*Calculating log of size and age
gen log_assets=ln(tnam)
gen logage=ln(date-date_inc+1)

*Calculating volatility of flows
tsset icdi time

gen L1Wflow=L.Wflow
gen L2Wflow=L2.Wflow
gen L3Wflow=L3.Wflow
gen L4Wflow=L4.Wflow
gen L5Wflow=L5.Wflow
gen L6Wflow=L6.Wflow
gen L7Wflow=L7.Wflow
gen L8Wflow=L8.Wflow
gen L9Wflow=L9.Wflow
gen L10Wflow=L10.Wflow
gen L11Wflow=L11.Wflow
egen flowvol=rsd(Wflow L1Wflow L2Wflow L3Wflow L4Wflow L5Wflow L6Wflow L7Wflow L8Wflow L9Wflow L10Wflow L11Wflow)


*Demeaning the control variables for interpretation purpose

*Conditioning on the RSI sample
gen sum1=logage+log_assets+expenses+Wturn+Wflow+load+covrsi31+flowvol

egen meanage1=mean(logage) if sum1~=.
egen meanasset1=mean(log_assets) if sum1~=.
egen meanexp1=mean(expenses) if sum1~=.
egen meanturn1=mean(Wturn) if sum1~=.
egen meanflow1=mean(Wflow) if sum1~=.
egen meanload1=mean(load) if sum1~=.
egen meanflowvol1=mean(flowvol) if sum1~=.

gen logage1=logage-meanage1
gen log_assets1=log_assets-meanasset1
gen expenses1=expenses-meanexp1
gen Wturn1=Wturn-meanturn1
gen Wflow1=Wflow-meanflow1
gen load1=load-meanload1
gen flowvol1=flowvol-meanflowvol1

*Conditioning on the RAI sample
gen sum2=logage+log_assets+expenses+Wturn+Wflow+load+covindeps+flowvol

egen meanage2=mean(logage) if sum2~=.
egen meanasset2=mean(log_assets) if sum2~=.
egen meanexp2=mean(expenses) if sum2~=.
egen meanturn2=mean(Wturn) if sum2~=.
egen meanflow2=mean(Wflow) if sum2~=.
egen meanload2=mean(load) if sum2~=.
egen meanflowvol2=mean(flowvol) if sum2~=.

gen logage2=logage-meanage2
gen log_assets2=log_assets-meanasset2
gen expenses2=expenses-meanexp2
gen Wturn2=Wturn-meanturn2
gen Wflow2=Wflow-meanflow2
gen load2=load-meanload2
gen flowvol2=flowvol-meanflowvol2


*Rescaling the dependent variables
gen RSI=covrsi31*10000
gen RAI=covindeps*10000

*Generating price of risk dummy (10% of highest defaultspread observations get dummy=1)
gen defdum=1 if defaultspread>2 & defaultspread~=.
replace defdum=0 if defaultspread<=2

*Ftiming (RAI) and Fpicking (RSI) regressions

tsset icdi time

reg RAI recession2 if sum2~=.,cluster(date)
outreg2 using "/Users/mkacperc/Stijn/Revision/ECTA/table2.xls", replace se bdec(3)
reg RAI recession2 logage2 log_assets2 expenses2 Wturn2 Wflow2 load2 flowvol2,cluster(date)
outreg2 using "/Users/mkacperc/Stijn/Revision/ECTA/table2.xls", append se bdec(3)
reg RAI defdum voldum32 logage2 log_assets2 expenses2 Wturn2 Wflow2 load2 flowvol2,cluster(date)
outreg2 using "/Users/mkacperc/Stijn/Revision/ECTA/table2.xls", append se bdec(3)
reg RSI recession2 if sum1~=.,cluster(date)
outreg2 using "/Users/mkacperc/Stijn/Revision/ECTA/table2.xls", append se bdec(3)
reg RSI recession2 logage1 log_assets1 expenses1 Wturn1 Wflow1 load1 flowvol1, cluster(date)
outreg2 using "/Users/mkacperc/Stijn/Revision/ECTA/table2.xls", append se bdec(3)
reg RSI defdum voldum32 logage1 log_assets1 expenses1 Wturn1 Wflow1 load1 flowvol1, cluster(date)
outreg2 using "/Users/mkacperc/Stijn/Revision/ECTA/table2.xls", append se bdec(3)

**************************************
*Table 3 (Dispersion in fund returns)*
**************************************
clear all

*Loading mutual fund data from CRSP (icdi, fundno, date, yearm, expenses, turnover, tnam, date_inc, load, retm)
use "/Users/mkacperc/Stijn/Revision/Data/returns2.dta"

*Merging recession data (Monthly data based on NBER recession dates from www.nber.org: date, recession2)
sort date
merge date using "/Users/mkacperc/Stijn/Revision/Data/recession_data.dta",nokeep
tab _merge
drop _merge

*Merging portfolio dispersion measures
sort icdi yearm
merge icdi yearm using "/Users/mkacperc/Stijn/Revision/Data/stockconc.dta",nokeep
drop _merge

*Merging volatility measure
sort yearm
merge yearm using "/Users/mkacperc/Stijn/Revision/Data/volcf.dta",nokeep
tab _merge
drop _merge

*Merging price of risk data (yearm, defaultspread=yield on BBB and AAA)
sort yearm
merge yearm using "/Users/mkacperc/Stijn/Revision/Data/dew_becker.dta",nokeep
tab _merge
drop _merge

*Calculating flows
tsset icdi time
flow=(tnam-L.tnam*(1+retm))/L.tnam

*Winsorizing fund controls
winsor flow,gen(Wflow) p(0.005)
winsor turnover,gen(Wturn) p(0.005)

*Calculating log of size and age
gen log_assets=ln(tnam)
gen logage=ln(date-date_inc+1)

*Calculating volatility of flows

tsset icdi time
gen L1Wflow=L.Wflow
gen L2Wflow=L2.Wflow
gen L3Wflow=L3.Wflow
gen L4Wflow=L4.Wflow
gen L5Wflow=L5.Wflow
gen L6Wflow=L6.Wflow
gen L7Wflow=L7.Wflow
gen L8Wflow=L8.Wflow
gen L9Wflow=L9.Wflow
gen L10Wflow=L10.Wflow
gen L11Wflow=L11.Wflow

egen flowvol=rsd(Wflow L1Wflow L2Wflow L3Wflow L4Wflow L5Wflow L6Wflow L7Wflow L8Wflow L9Wflow L10Wflow L11Wflow)

*Generating fund abnormal return
gen retmktfund=retm-mkt

*Winsorizing measures
winsor retmktfund,gen(Wretmktfund) p(0.005)
winsor mktbeta,gen(Wmktbeta) p(0.025)

*Demeaning the control variables for interpretation purpose
gen sum=logage+log_assets+expenses+Wturn+Wflow+load+siz+val+mom+flowvol

egen meanage=mean(logage) if sum~=.
egen meanasset=mean(log_assets) if sum~=.
egen meanexp=mean(expenses) if sum~=.
egen meanturn=mean(Wturn) if sum~=.
egen meanflow=mean(Wflow) if sum~=.
egen meanload=mean(load) if sum~=.
egen meanval=mean(val) if sum~=.
egen meansiz=mean(siz) if sum~=.
egen meanmom=mean(mom) if sum~=.
egen meanflowvol=mean(flowvol) if sum~=.

replace logage=logage-meanage
replace log_assets=log_assets-meanasset
replace expenses=expenses-meanexp
replace Wturn=Wturn-meanturn
replace Wflow=Wflow-meanflow
replace load=load-meanload
replace val=val-meanval
replace siz=siz-meansiz
replace mom=mom-meanmom
replace flowvol=flowvol-meanflowvol

sort date
by date: egen meanretmkt=mean(Wretmktfund)
by date: egen meanbeta=mean(Wmktbeta)

gen stdretmkt=abs(Wretmktfund-meanretmkt)
gen stdbeta=abs(Wmktbeta-meanbeta)

*Expressing dispersion measures in percent terms
replace stdretmkt=stdretmkt*100
rename di2 stockconc
replace stockconc=stockconc*100

*Generating price of risk dummy (10% of highest defaultspread observations get dummy=1)
gen defdum=1 if defaultspread>2 & defaultspread~=.
replace defdum=0 if defaultspread<=2

*Table 3: Regressions
reg stockconc recession2 if sum~=.,cluster(icdi)
outreg2 using "/Users/mkacperc/Stijn/Revision/ECTA/table3.xls", replace se bdec(3) noaster
reg stockconc recession2 logage log_assets expenses Wturn Wflow load siz val mom flowvol,cluster(icdi)
outreg2 using "/Users/mkacperc/Stijn/Revision/ECTA/table3.xls", append se bdec(3) noaster
reg stdbeta recession2 if sum~=.,cluster(date)
outreg2 using "/Users/mkacperc/Stijn/Revision/ECTA/table3.xls", append se bdec(3) noaster
reg stdbeta recession2 logage log_assets expenses Wturn Wflow load siz val mom flowvol,cluster(date)
outreg2 using "/Users/mkacperc/Stijn/Revision/ECTA/table3.xls", append se bdec(3) noaster
reg stdretmkt recession2 if sum~=.,cluster(date)
outreg2 using "/Users/mkacperc/Stijn/Revision/ECTA/table3.xls", append se bdec(3) noaster
reg stdretmkt recession2 logage log_assets expenses Wturn Wflow load siz val mom flowvol,cluster(date)
outreg2 using "/Users/mkacperc/Stijn/Revision/ECTA/table3.xls", append se bdec(3) noaster
reg stdretmkt defdum voldum32 logage log_assets expenses Wturn Wflow load siz val mom flowvol,cluster(date)
outreg2 using "/Users/mkacperc/Stijn/Revision/ECTA/table3.xls", append se bdec(3) noaster

*******************************************************
*Table 4 (Fund performance - cross-sectional approach)*
*******************************************************

clear all

*Loading mutual fund data from CRSP (icdi, fundno, date, yearm, expenses, turnover, tnam, date_inc, load, retm)
use "/Users/mkacperc/Stijn/Revision/Data/returns2.dta"

*Merging recession data (Monthly data based on NBER recession dates from www.nber.org: date, recession2)
sort date
merge date using "/Users/mkacperc/Stijn/Revision/Data/recession_data.dta",nokeep
tab _merge
drop _merge

*Merging fund alphas (the input file is based on Matlab file alphafund_new.m)
sort id time
merge id time using "/Users/mkacperc/Stijn/Revision/Data/fundalphas.dta",nokeep
drop _merge

*Merging volatility measure
sort yearm
merge yearm using "/Users/mkacperc/Stijn/Revision/Data/volcf.dta",nokeep
tab _merge
drop _merge

*Merging price of risk data (yearm, defaultspread=yield on BBB and AAA)
sort yearm
merge yearm using "/Users/mkacperc/Stijn/Revision/Data/dew_becker.dta",nokeep
tab _merge
drop _merge

*Calculating flows
tsset icdi time
flow=(tnam-L.tnam*(1+retm))/L.tnam

*Winsorizing fund controls
winsor flow,gen(Wflow) p(0.005)
winsor turnover,gen(Wturn) p(0.005)

*Calculating log of size and age
gen log_assets=ln(tnam)
gen logage=ln(date-date_inc+1)

*Calculating volatility of flows

tsset icdi time

gen L1Wflow=L.Wflow
gen L2Wflow=L2.Wflow
gen L3Wflow=L3.Wflow
gen L4Wflow=L4.Wflow
gen L5Wflow=L5.Wflow
gen L6Wflow=L6.Wflow
gen L7Wflow=L7.Wflow
gen L8Wflow=L8.Wflow
gen L9Wflow=L9.Wflow
gen L10Wflow=L10.Wflow
gen L11Wflow=L11.Wflow

egen flowvol=rsd(Wflow L1Wflow L2Wflow L3Wflow L4Wflow L5Wflow L6Wflow L7Wflow L8Wflow L9Wflow L10Wflow L11Wflow)

*Generating fund abnormal return
gen retmktfund=retm-mkt

*Winsorizing main variables
winsor retmktfund,gen(Wretmktfund) p(0.005)
winsor fundcapmalpha,gen(Wfundcapmalpha) p(0.025)
winsor fundffalpha,gen(Wfundffalpha) p(0.025)
winsor fundcaralpha,gen(Wfundcaralpha) p(0.025)

*Demeaning the series for interpretation reasons
gen sum=logage+log_assets+expenses+Wturn+Wflow+load+siz+val+mom+fundcapmalpha+flowvol

egen meanage=mean(logage) if sum~=.
egen meanasset=mean(log_assets) if sum~=.
egen meanexp=mean(expenses) if sum~=.
egen meanturn=mean(Wturn) if sum~=.
egen meanflow=mean(Wflow) if sum~=.
egen meanload=mean(load) if sum~=.
egen meanval=mean(val) if sum~=.
egen meansiz=mean(siz) if sum~=.
egen meanmom=mean(mom) if sum~=.
egen meanflowvol=mean(flowvol) if sum~=.

replace logage=logage-meanage
replace log_assets=log_assets-meanasset
replace expenses=expenses-meanexp
replace Wturn=Wturn-meanturn
replace Wflow=Wflow-meanflow
replace load=load-meanload
replace val=val-meanval
replace siz=siz-meansiz
replace mom=mom-meanmom
replace flowvol=flowvol-meanflowvol

sort date

by date: egen meanretmkt=mean(Wretmktfund)
by date: egen meana1=mean(Wfundcapmalpha)
by date: egen meana3=mean(Wfundffalpha)
by date: egen meana4=mean(Wfundcaralpha)

*Expressing returns in percent
replace Wretmktfund=Wretmktfund*100
replace Wfundcapmalpha=Wfundcapmalpha*100
replace Wfundffalpha=Wfundffalpha*100
replace Wfundcaralpha=Wfundcaralpha*100

*Generating price of risk dummy (10% of highest defaultspread observations get dummy=1)
gen defdum=1 if defaultspread>2 & defaultspread~=.
replace defdum=0 if defaultspread<=2

tsset icdi date

reg Wretmktfund recession2 if sum~=.,cluster(date)
outreg2 using "/Users/mkacperc/Stijn/Revision/ECTA/table4.xls", replace se bdec(3) noaster
reg Wretmktfund recession2 logage log_assets expenses Wturn Wflow load siz val mom flowvol,cluster(date)
outreg2 using "/Users/mkacperc/Stijn/Revision/ECTA/table4.xls", append se bdec(3) noaster
reg Wfundcapmalpha recession2 if sum~=.,cluster(date)
outreg2 using "/Users/mkacperc/Stijn/Revision/ECTA/table4.xls", append se bdec(3) noaster
reg Wfundcapmalpha recession2 logage log_assets expenses Wturn Wflow load siz val mom flowvol,cluster(date)
outreg2 using "/Users/mkacperc/Stijn/Revision/ECTA/table4.xls", append se bdec(3) noaster
reg Wfundffalpha recession2 if sum~=.,cluster(date)
outreg2 using "/Users/mkacperc/Stijn/Revision/ECTA/table4.xls", append se bdec(3) noaster
reg Wfundffalpha recession2 logage log_assets expenses Wturn Wflow load siz val mom flowvol,cluster(date)
outreg2 using "/Users/mkacperc/Stijn/Revision/ECTA/table4.xls", append se bdec(3) noaster
reg Wfundcaralpha recession2 if sum~=.,cluster(date)
outreg2 using "/Users/mkacperc/Stijn/Revision/ECTA/table4.xls", append se bdec(3) noaster
reg Wfundcaralpha recession2 logage log_assets expenses Wturn Wflow load siz val mom flowvol,cluster(date)
outreg2 using "/Users/mkacperc/Stijn/Revision/ECTA/table4.xls", append se bdec(3) noaster
reg Wfundcaralpha defdum voldum32 logage log_assets expenses Wturn Wflow load siz val mom ,cluster(icdi)
outreg2 using "/Users/mkacperc/Stijn/Revision/ECTA/table4.xls", append se bdec(3) noaster

************************
*ONLINE APPENDIX TABLES*
************************

*********************************
*Table S4 (Comparison with CLMX)*
*********************************
clear all

*Loading the data with stock beta^2*variance of stocks (aggregate shock)
insheet using "/Users/mkacperc/Stijn/Revision/Data/betasqvolstock.txt"

rename v1 betasqvolstock
rename v2 id
rename v3 time

drop if betasqvolstock==-99
drop v4

*Saving the aggregate shock data
sort id time
save "/Users/mkacperc/Stijn/Revision/Data/aggvolstock.dta",replace

clear all

*Loading the data with idiosyncratic shock (volatility of epsilon from the market model regression)
insheet using "/Users/mkacperc/Stijn/Revision/Data/sigepsstock.txt"

rename v1 sigepsstock
rename v2 id
rename v3 time

drop if sigepsstock==-99
drop v4

*Saving idiosyncratic shock data
sort id time
save "/Users/mkacperc/Stijn/Revision/Data/sigepsstock.dta",replace

*Generating a file with recessions based on NBER definitions (input file should just include time dimension: yearmm)

clear all
use "/Users/mkacperc/Stijn/Revision/Data/recessions_long.dta"

replace recession2=1 if yearm>=192610 & yearm<=192711
replace recession2=1 if yearm>=192908 & yearm<=193303
replace recession2=1 if yearm>=193705 & yearm<=193806
replace recession2=1 if yearm>=194502 & yearm<=194510
replace recession2=1 if yearm>=194811 & yearm<=194910
replace recession2=1 if yearm>=195307 & yearm<=195405
replace recession2=1 if yearm>=195708 & yearm<=195804
replace recession2=1 if yearm>=196004 & yearm<=196102
replace recession2=1 if yearm>=196912 & yearm<=197011
replace recession2=1 if yearm>=197311 & yearm<=197503
replace recession2=1 if yearm>=198001 & yearm<=198007
replace recession2=1 if yearm>=198107 & yearm<=198211
replace recession2=1 if yearm>=199007 & yearm<=199103
replace recession2=1 if yearm>=200103 & yearm<=200111
replace recession2=1 if yearm>=200712 & yearm<=200812

sort yearm

save "/Users/mkacperc/Stijn/Revision/Data/recessions_long.dta",replace

clear all

*Load the data with stock level prices, mktcap, and factors (the input file is obtained using the code stockbetasqvol.do)
use "/Users/mkacperc/Stijn/Revision/Data/idioaggstock_2608.dta"

*Merging the data with idiosyncratic risk (the input file is based on the Matlab code rsqstocks_new.m)
sort id time
merge id time using "/Users/mkacperc/Stijn/Revision/Data/sigepsstock.dta"
tab _merge
drop _merge

*Merging the data with aggregate risk (the input file is based on the Matlab code rsqstocks_new.m)
sort id time
merge id time using "/Users/mkacperc/Stijn/Revision/Data/aggvolstock.dta"
tab _merge
drop _merge

drop if sigepsstock==. | size==.

*Generating market weights
sort time
by time: egen totsize=sum(size)
gen weight=size/totsize

*Winsrizing risk measures
winsor sigepsstock,gen(Wsigepsstock) p(0.005)
winsor betasqvolstock,gen(Wbetasqvolstock) p(0.005)

*Caluclating equal-weighted and value-weighted risk measures
tsset permno time
gen prodsigeps=weight*Wsigepsstock
gen prodbetasq=weight*Wbetasqvolstock

sort time
by time: egen avgsigepsagg=mean(Wsigepsstock)
by time: egen avgbetasqvolagg=mean(Wbetasqvolstock)

by time: egen wsigepsagg=sum(prodsigeps)
by time: egen wbetasqvolagg=sum(prodbetasq)

*Merging the data on recessions
sort yearm
merge yearm using "/Users/mkacperc/Stijn/Revision/Data/recessions_long.dta",nokeep
tab _merge

drop _merge

keep yearm time recession2 avgsigepsagg avgbetasqvolagg wsigepsagg wbetasqvolagg mktrf smb hml mom

duplicates drop

sort time
by time: egen n=seq()
sort n time

*Expressing main quantities in percent terms
gen avgsigmktagg=sqrt(avgbetasqvolagg)*100
gen wsigmktagg=sqrt(wbetasqvolagg)*100

replace avgsigepsagg=avgsigepsagg*100
replace avgbetasqvolagg=avgbetasqvolagg*100
replace wsigepsagg=wsigepsagg*100
replace wbetasqvolagg=wbetasqvolagg*100

*Table 1 (time-series regression)

*Equal-weighted results
tsset time

*1980-2005
newey avgsigmktagg recession2 mktrf smb hml mom if n==1 & yearm>198003 & yearm<200600,lag(4)
outreg2 using "/Users/mkacperc/Stijn/Revision/ECTA/tableS4a.xls", replace se bdec(3)
newey avgsigepsagg recession2 mktrf smb hml mom if n==1 & yearm>198003 & yearm<200600,lag(4)
outreg2 using "/Users/mkacperc/Stijn/Revision/ECTA/tableS4a.xls", append se bdec(3)

*1926/07-2008
newey avgsigmktagg recession2 mktrf smb hml mom if n==1,lag(4)
outreg2 using "/Users/mkacperc/Stijn/Revision/ECTA/tableS4a.xls", append se bdec(3)
newey avgsigepsagg recession2 mktrf smb hml mom if n==1,lag(4)
outreg2 using "/Users/mkacperc/Stijn/Revision/ECTA/tableS4a.xls", append se bdec(3)

*1962-1997
newey avgsigmktagg recession2 mktrf smb hml mom if n==1 & yearm>196200 & yearm<199800,lag(4)
outreg2 using "/Users/mkacperc/Stijn/Revision/ECTA/tableS4a.xls", append se bdec(3)
newey avgsigepsagg recession2 mktrf smb hml mom if n==1 & yearm>196200 & yearm<199800,lag(4)
outreg2 using "/Users/mkacperc/Stijn/Revision/ECTA/tableS4a.xls", append se bdec(3)

*1962-2005
newey avgsigmktagg recession2 mktrf smb hml mom if n==1 & yearm>196200 & yearm<200600,lag(4)
outreg2 using "/Users/mkacperc/Stijn/Revision/ECTA/tableS4a.xls", append se bdec(3)
newey avgsigepsagg recession2 mktrf smb hml mom if n==1 & yearm>196200 & yearm<200600,lag(4)
outreg2 using "/Users/mkacperc/Stijn/Revision/ECTA/tableS4a.xls", append se bdec(3)

*Value-weighted results

*1980-2005
newey wsigmktagg recession2 mktrf smb hml mom if n==1 & yearm>198003 & yearm<200600,lag(4)
outreg2 using "/Users/mkacperc/Stijn/Revision/ECTA/tableS4b.xls", replace se bdec(3)
newey wsigepsagg recession2 mktrf smb hml mom if n==1 & yearm>198003 & yearm<200600,lag(4)
outreg2 using "/Users/mkacperc/Stijn/Revision/ECTA/tableS4b.xls", append se bdec(3)

*1926/07-2008
newey wsigmktagg recession2 mktrf smb hml mom if n==1,lag(4)
outreg2 using "/Users/mkacperc/Stijn/Revision/ECTA/tableS4b.xls", append se bdec(3)
newey wsigepsagg recession2 mktrf smb hml mom if n==1,lag(4)
outreg2 using "/Users/mkacperc/Stijn/Revision/ECTA/tableS4b.xls", append se bdec(3)

*1962-1997
newey wsigmktagg recession2 mktrf smb hml mom if n==1 & yearm>196200 & yearm<199800,lag(4)
outreg2 using "/Users/mkacperc/Stijn/Revision/ECTA/tableS4b.xls", append se bdec(3)
newey wsigepsagg recession2 mktrf smb hml mom if n==1 & yearm>196200 & yearm<199800,lag(4)
outreg2 using "/Users/mkacperc/Stijn/Revision/ECTA/tableS4b.xls", append se bdec(3)

*1962-2005
newey wsigmktagg recession2 mktrf smb hml mom if n==1 & yearm>196200 & yearm<200600,lag(4)
outreg2 using "/Users/mkacperc/Stijn/Revision/ECTA/tableS4b.xls", append se bdec(3)
newey wsigepsagg recession2 mktrf smb hml mom if n==1 & yearm>196200 & yearm<200600,lag(4)
outreg2 using "/Users/mkacperc/Stijn/Revision/ECTA/tableS4b.xls", append se bdec(3)


***********************************************
*Table S5 (Nonlinear volatility and attention)*
***********************************************

clear all

*Loading mutual fund data from CRSP (icdi, fundno, date, yearm, expenses, turnover, tnam, date_inc, load, retm)
use "/Users/mkacperc/Stijn/Revision/Data/returns2.dta"

*Merging recession data (Monthly data based on NBER recession dates from www.nber.org: date, recession2)
sort date
merge date using "/Users/mkacperc/Stijn/Revision/Data/recession_data.dta",nokeep
tab _merge
drop _merge

*Merging volatility data
sort yearm
merge yearm using "/Users/mkacperc/Stijn/Revision/Data/volcf.dta",nokeep
tab _merge
drop _merge

*Merging Ftiming data (this comes from the output in Matlab file covarindeps.m)
sort fundno yearm
merge fundno yearm using "/Users/mkacperc/Stijn/Revision/Data/covindeps.dta",nokeep
tab _merge
drop _merge

*Merging Fpicking data (this comes from the output in Matlab file covarsue31.m)
sort fundno yearm
merge fundno yearm using "/Users/mkacperc/Stijn/Revision/Data/rsi_new.dta",nokeep
tab _merge
drop _merge

*Calculating flows
tsset icdi time
flow=(tnam-L.tnam*(1+retm))/L.tnam

*Winsorizing fund controls
winsor flow,gen(Wflow) p(0.005)
winsor turnover,gen(Wturn) p(0.005)

*Calculating log of size and age
gen log_assets=ln(tnam)
gen logage=ln(date-date_inc+1)

*Calculating volatility of flows
tsset icdi time

gen L1Wflow=L.Wflow
gen L2Wflow=L2.Wflow
gen L3Wflow=L3.Wflow
gen L4Wflow=L4.Wflow
gen L5Wflow=L5.Wflow
gen L6Wflow=L6.Wflow
gen L7Wflow=L7.Wflow
gen L8Wflow=L8.Wflow
gen L9Wflow=L9.Wflow
gen L10Wflow=L10.Wflow
gen L11Wflow=L11.Wflow
egen flowvol=rsd(Wflow L1Wflow L2Wflow L3Wflow L4Wflow L5Wflow L6Wflow L7Wflow L8Wflow L9Wflow L10Wflow L11Wflow)

*Demeaning the control variables for interpretation purpose

gen sum1=logage+log_assets+expenses+Wturn+Wflow+load+covrsi31+flowvol

egen meanage1=mean(logage) if sum1~=.
egen meanasset1=mean(log_assets) if sum1~=.
egen meanexp1=mean(expenses) if sum1~=.
egen meanturn1=mean(Wturn) if sum1~=.
egen meanflow1=mean(Wflow) if sum1~=.
egen meanload1=mean(load) if sum1~=.
egen meanflowvol1=mean(flowvol) if sum1~=.

gen logage1=logage-meanage1
gen log_assets1=log_assets-meanasset1
gen expenses1=expenses-meanexp1
gen Wturn1=Wturn-meanturn1
gen Wflow1=Wflow-meanflow1
gen load1=load-meanload1
gen flowvol1=flowvol-meanflowvol1

gen sum2=logage+log_assets+expenses+Wturn+Wflow+load+covindeps+flowvol

egen meanage2=mean(logage) if sum2~=.
egen meanasset2=mean(log_assets) if sum2~=.
egen meanexp2=mean(expenses) if sum2~=.
egen meanturn2=mean(Wturn) if sum2~=.
egen meanflow2=mean(Wflow) if sum2~=.
egen meanload2=mean(load) if sum2~=.
egen meanflowvol2=mean(flowvol) if sum2~=.

gen logage2=logage-meanage2
gen log_assets2=log_assets-meanasset2
gen expenses2=expenses-meanexp2
gen Wturn2=Wturn-meanturn2
gen Wflow2=Wflow-meanflow2
gen load2=load-meanload2
gen flowvol2=flowvol-meanflowvol2

gen RSI=covrsi31*10000
gen RAI=covindeps*10000

*Creating volatility dummy variables

gen vol5=1 if F6realvol>0.185 & F6realvol~=.
replace vol5=0 if vol5==.

gen vol10=1 if F6realvol>=0.1416 & F6realvol<=0.185
replace vol10=0 if vol10==.

gen vol30=1 if F6realvol>=0.092 & F6realvol<=0.1416
replace vol30=0 if vol30==.

gen vol70=1 if F6realvol>=0.0425 & F6realvol<=0.092
replace vol70=0 if vol70==.

*spline volatility
gen vol1=F6realvol if recession2==1
replace vol1=0 if vol1==.
gen vol2=F6realvol if recession2==0
replace vol2=0 if vol2==.

*Fpicking(RSI) and Ftiming(RAI) regressions

reg RAI vol5 vol10 vol30 vol70 logage2 log_assets2 expenses2 Wturn2 Wflow2 load2 flowvol2, cluster(date)
outreg2 using "/Users/mkacperc/Stijn/Revision/ECTA/tableS5.xls", replace se bdec(3)
reg RAI recession2 vol5 vol10 vol30 vol70 logage2 log_assets2 expenses2 Wturn2 Wflow2 load2 flowvol2, cluster(date)
outreg2 using "/Users/mkacperc/Stijn/Revision/ECTA/tableS5.xls", append se bdec(3)
reg RAI vol1 vol2 logage2 log_assets2 expenses2 Wturn2 Wflow2 load2 flowvol2, cluster(date)
outreg2 using "/Users/mkacperc/Stijn/Revision/ECTA/tableS5.xls", append se bdec(3)
reg RSI vol5 vol10 vol30 vol70 logage1 log_assets1 expenses1 Wturn1 Wflow1 load1 flowvol1, cluster(date)
outreg2 using "/Users/mkacperc/Stijn/Revision/ECTA/tableS5.xls", append se bdec(3)
reg RSI recession2 vol5 vol10 vol30 vol70 logage1 log_assets1 expenses1 Wturn1 Wflow1 load1 flowvol1, cluster(date)
outreg2 using "/Users/mkacperc/Stijn/Revision/ECTA/tableS5.xls", append se bdec(3)
reg RSI vol1 vol2 logage1 log_assets1 expenses1 Wturn1 Wflow1 load1 flowvol1, cluster(date)
outreg2 using "/Users/mkacperc/Stijn/Revision/ECTA/tableS5.xls", append se bdec(3)


***************************************************************
*Table S6 Nonlinear volatility and dispersion in fund returns)*
***************************************************************

clear all

*Loading mutual fund data from CRSP (icdi, fundno, date, yearm, expenses, turnover, tnam, date_inc, load, retm)
use "/Users/mkacperc/Stijn/Revision/Data/returns2.dta"

*Merging recession data (Monthly data based on NBER recession dates from www.nber.org: date, recession2)
sort date
merge date using "/Users/mkacperc/Stijn/Revision/Data/recession_data.dta",nokeep
tab _merge
drop _merge

*Merging portfolio dispersion measures
sort icdi yearm
merge icdi yearm using "/Users/mkacperc/Stijn/Revision/Data/stockconc.dta",nokeep
drop _merge

*Merging volatility measure
sort yearm
merge yearm using "/Users/mkacperc/Stijn/Revision/Data/volcf.dta",nokeep
tab _merge
drop _merge

*Merging price of risk measure
sort yearm
merge yearm using "/Users/mkacperc/Stijn/Revision/Data/dew_becker.dta",nokeep
tab _merge
drop _merge

*Calculating flows
tsset icdi time
flow=(tnam-L.tnam*(1+retm))/L.tnam

*Winsorizing fund controls
winsor flow,gen(Wflow) p(0.005)
winsor turnover,gen(Wturn) p(0.005)

*Calculating log of size and age
gen log_assets=ln(tnam)
gen logage=ln(date-date_inc+1)

*Calculating volatility of flows

tsset icdi time
gen L1Wflow=L.Wflow
gen L2Wflow=L2.Wflow
gen L3Wflow=L3.Wflow
gen L4Wflow=L4.Wflow
gen L5Wflow=L5.Wflow
gen L6Wflow=L6.Wflow
gen L7Wflow=L7.Wflow
gen L8Wflow=L8.Wflow
gen L9Wflow=L9.Wflow
gen L10Wflow=L10.Wflow
gen L11Wflow=L11.Wflow

egen flowvol=rsd(Wflow L1Wflow L2Wflow L3Wflow L4Wflow L5Wflow L6Wflow L7Wflow L8Wflow L9Wflow L10Wflow L11Wflow)


*Generating fund abnormal return
gen retmktfund=retm-mkt

*Winsorizing main variables
winsor retmktfund,gen(Wretmktfund) p(0.005)

*Demeaning the series for interpretation reasons
gen sum=logage+log_assets+expenses+Wturn+Wflow+load+siz+val+mom+flowvol

egen meanage=mean(logage) if sum~=.
egen meanasset=mean(log_assets) if sum~=.
egen meanexp=mean(expenses) if sum~=.
egen meanturn=mean(Wturn) if sum~=.
egen meanflow=mean(Wflow) if sum~=.
egen meanload=mean(load) if sum~=.
egen meanval=mean(val) if sum~=.
egen meansiz=mean(siz) if sum~=.
egen meanmom=mean(mom) if sum~=.
egen meanflowvol=mean(flowvol) if sum~=.

replace logage=logage-meanage
replace log_assets=log_assets-meanasset
replace expenses=expenses-meanexp
replace Wturn=Wturn-meanturn
replace Wflow=Wflow-meanflow
replace load=load-meanload
replace val=val-meanval
replace siz=siz-meansiz
replace mom=mom-meanmom
replace flowvol=flowvol-meanflowvol

sort date
by date: egen meanretmkt=mean(Wretmktfund)
gen stdretmkt=abs(Wretmktfund-meanretmkt)

*Expressing dispersion measures in percent terms
replace stdretmkt=stdretmkt*100
rename di2 stockconc
replace stockconc=stockconc*100

*Creating volatility dummy variables

gen vol5=1 if F6realvol>0.185 & F6realvol~=.
replace vol5=0 if vol5==.

gen vol10=1 if F6realvol>=0.1416 & F6realvol<=0.185
replace vol10=0 if vol10==.

gen vol30=1 if F6realvol>=0.092 & F6realvol<=0.1416
replace vol30=0 if vol30==.

gen vol70=1 if F6realvol>=0.0425 & F6realvol<=0.092
replace vol70=0 if vol70==.

*spline volatility
gen vol1=F6realvol if recession2==1
replace vol1=0 if vol1==.
gen vol2=F6realvol if recession2==0
replace vol2=0 if vol2==.

reg stdretmkt vol5 vol10 vol30 vol70 logage log_assets expenses Wturn Wflow load siz val mom flowvol,cluster(date)
outreg2 using "/Users/mkacperc/Stijn/Revision/ECTA/tableS6.xls", replace se bdec(3)
reg stdretmkt recession2 vol5 vol10 vol30 vol70 logage log_assets expenses Wturn Wflow load siz val mom flowvol,cluster(date)
outreg2 using "/Users/mkacperc/Stijn/Revision/ECTA/tableS6.xls", append se bdec(3)
reg stdretmkt vol1 vol2 logage log_assets expenses Wturn Wflow load siz val mom flowvol,cluster(date)
outreg2 using "/Users/mkacperc/Stijn/Revision/ECTA/tableS6.xls", append se bdec(3)

****************************************************
*Table S7 Fund performance and nonlinear volatility*
****************************************************

clear all

*Loading mutual fund data from CRSP (icdi, fundno, date, yearm, expenses, turnover, tnam, date_inc, load, retm)
use "/Users/mkacperc/Stijn/Revision/Data/returns2.dta"

*Merging recession data (Monthly data based on NBER recession dates from www.nber.org: date, recession2)
sort date
merge date using "/Users/mkacperc/Stijn/Revision/Data/recession_data.dta",nokeep
tab _merge
drop _merge

*Merging fund alphas (the input file is based on Matlab file alphafund_new.m)
sort id time
merge id time using "/Users/mkacperc/Stijn/Revision/Data/fundalphas.dta",nokeep
drop _merge

*Merging volatility measure
sort yearm
merge yearm using "/Users/mkacperc/Stijn/Revision/Data/volcf.dta",nokeep
tab _merge
drop _merge

*Calculating flows
tsset icdi time
flow=(tnam-L.tnam*(1+retm))/L.tnam

*Winsorizing fund controls
winsor flow,gen(Wflow) p(0.005)
winsor turnover,gen(Wturn) p(0.005)

*Calculating log of size and age
gen log_assets=ln(tnam)
gen logage=ln(date-date_inc+1)

*Calculating volatility of flows

tsset icdi time

gen L1Wflow=L.Wflow
gen L2Wflow=L2.Wflow
gen L3Wflow=L3.Wflow
gen L4Wflow=L4.Wflow
gen L5Wflow=L5.Wflow
gen L6Wflow=L6.Wflow
gen L7Wflow=L7.Wflow
gen L8Wflow=L8.Wflow
gen L9Wflow=L9.Wflow
gen L10Wflow=L10.Wflow
gen L11Wflow=L11.Wflow

egen flowvol=rsd(Wflow L1Wflow L2Wflow L3Wflow L4Wflow L5Wflow L6Wflow L7Wflow L8Wflow L9Wflow L10Wflow L11Wflow)

winsor fundcaralpha,gen(Wfundcaralpha) p(0.025)

*Demeaning the series for interpretation reasons

gen sum=logage+log_assets+expenses+Wturn+Wflow+load+siz+val+mom+fundcapmalpha+flowvol

egen meanage=mean(logage) if sum~=.
egen meanasset=mean(log_assets) if sum~=.
egen meanexp=mean(expenses) if sum~=.
egen meanturn=mean(Wturn) if sum~=.
egen meanflow=mean(Wflow) if sum~=.
egen meanload=mean(load) if sum~=.
egen meanval=mean(val) if sum~=.
egen meansiz=mean(siz) if sum~=.
egen meanmom=mean(mom) if sum~=.
egen meanflowvol=mean(flowvol) if sum~=.

replace logage=logage-meanage
replace log_assets=log_assets-meanasset
replace expenses=expenses-meanexp
replace Wturn=Wturn-meanturn
replace Wflow=Wflow-meanflow
replace load=load-meanload
replace val=val-meanval
replace siz=siz-meansiz
replace mom=mom-meanmom
replace flowvol=flowvol-meanflowvol

sort date

by date: egen meana4=mean(Wfundcaralpha)
replace Wfundcaralpha=Wfundcaralpha*100

*Creating volatility dummy variables

gen vol5=1 if F6realvol>0.185 & F6realvol~=.
replace vol5=0 if vol5==.

gen vol10=1 if F6realvol>=0.1416 & F6realvol<=0.185
replace vol10=0 if vol10==.

gen vol30=1 if F6realvol>=0.092 & F6realvol<=0.1416
replace vol30=0 if vol30==.

gen vol70=1 if F6realvol>=0.0425 & F6realvol<=0.092
replace vol70=0 if vol70==.

*spline volatility
gen vol1=F6realvol if recession2==1
replace vol1=0 if vol1==.
gen vol2=F6realvol if recession2==0
replace vol2=0 if vol2==.

reg Wfundcaralpha vol5 vol10 vol30 vol70 logage log_assets expenses Wturn Wflow load siz val mom flowvol,cluster(date)
outreg2 using "/Users/mkacperc/Stijn/Revision/ECTA/tableS7.xls", replace se bdec(3)
reg Wfundcaralpha recession2 vol5 vol10 vol30 vol70 logage log_assets expenses Wturn Wflow load siz val mom flowvol,cluster(date)
outreg2 using "/Users/mkacperc/Stijn/Revision/ECTA/tableS7.xls", append se bdec(3)
reg Wfundcaralpha vol1 vol2 logage log_assets expenses Wturn Wflow load siz val mom flowvol,cluster(date)
outreg2 using "/Users/mkacperc/Stijn/Revision/ECTA/tableS7.xls", append se bdec(3)


***************************************
*Table S8 Results at the Manager level*
***************************************

*************************************************
*Attention results (manager level fixed effects)*
*************************************************

clear all

*Loading mutual fund data from CRSP at the manager level (hand constructed mapping between managers and funds in CRSP appended by individual web searches)
*Unit of observation mancode1 year month

use "/Users/mkacperc/Stijn/Revision/Data/turn_data.dta"

keep icdi mancode1 year month

*Merging mutual fund data from CRSP (icdi, fundno, date, year, month, yearm, expenses, turnover, tnam, date_inc, load, retm)
sort icdi year month
merge icdi year month using "/Users/mkacperc/Stijn/Revision/Data/returns2.dta",nokeep
tab _merge
drop _merge

*Merging recession data (Monthly data based on NBER recession dates from www.nber.org: date, recession2)
sort date
merge date using "/Users/mkacperc/Stijn/Revision/Data/recession_data.dta",nokeep
tab _merge
drop _merge

*Merging Ftiming data (this comes from the output in Matlab file covarindeps.m)
sort fundno yearm
merge fundno yearm using "/Users/mkacperc/Stijn/Revision/Data/covindeps.dta",nokeep
tab _merge
drop _merge

*Merging Fpicking data (this comes from the output in Matlab file covarsue31.m)
sort fundno yearm
merge fundno yearm using "/Users/mkacperc/Stijn/Revision/Data/rsi_new.dta",nokeep
tab _merge
drop _merge

*Calculating flows
tsset icdi time
flow=(tnam-L.tnam*(1+retm))/L.tnam

*Winsorizing fund controls
winsor flow,gen(Wflow) p(0.005)
winsor turnover,gen(Wturn) p(0.005)

*Calculating log of size and age
gen log_assets=ln(tnam)
gen logage=ln(date-date_inc+1)

*Demeaning the series for interpretation reasons

gen sum1=logage+log_assets+expenses+Wturn+Wflow+load+covrsi31

egen meanage1=mean(logage) if sum1~=.
egen meanasset1=mean(log_assets) if sum1~=.
egen meanexp1=mean(expenses) if sum1~=.
egen meanturn1=mean(Wturn) if sum1~=.
egen meanflow1=mean(Wflow) if sum1~=.
egen meanload1=mean(load) if sum1~=.

gen logage1=logage-meanage1
gen log_assets1=log_assets-meanasset1
gen expenses1=expenses-meanexp1
gen Wturn1=Wturn-meanturn1
gen Wflow1=Wflow-meanflow1
gen load1=load-meanload1

gen sum2=logage+log_assets+expenses+Wturn+Wflow+load+covindeps

egen meanage2=mean(logage) if sum2~=.
egen meanasset2=mean(log_assets) if sum2~=.
egen meanexp2=mean(expenses) if sum2~=.
egen meanturn2=mean(Wturn) if sum2~=.
egen meanflow2=mean(Wflow) if sum2~=.
egen meanload2=mean(load) if sum2~=.

gen logage2=logage-meanage2
gen log_assets2=log_assets-meanasset2
gen expenses2=expenses-meanexp2
gen Wturn2=Wturn-meanturn2
gen Wflow2=Wflow-meanflow2
gen load2=load-meanload2

gen RSI=covrsi31*10000
gen RAI=covindeps*10000

*RSI and RAI regressions

reg RAI recession2 logage2 log_assets2 expenses2 Wturn2 Wflow2 load2, cluster(date)
outreg2 using "/Users/mkacperc/Stijn/Revision/ECTA/tableS8.xls", replace se bdec(3)
areg RAI recession2 logage2 log_assets2 expenses2 Wturn2 Wflow2 load2,absorb(mancode1) cluster(date)
outreg2 using "/Users/mkacperc/Stijn/Revision/ECTA/tableS8.xls", append se bdec(3)
reg RSI recession2 logage1 log_assets1 expenses1 Wturn1 Wflow1 load1,cluster(date)
outreg2 using "/Users/mkacperc/Stijn/Revision/ECTA/tableS8.xls", append se bdec(3)
areg RSI recession2 logage1 log_assets1 expenses1 Wturn1 Wflow1 load1,absorb(mancode1) cluster(date)
outreg2 using "/Users/mkacperc/Stijn/Revision/ECTA/tableS8.xls", append se bdec(3)

**************************************************
*Dispersion results (manager level fixed effects)*
**************************************************

clear all

*Loading mutual fund data from CRSP at the manager level (hand constructed mapping between managers and funds in CRSP appended by individual web searches)
*Unit of observation mancode1 year month

use "/Users/mkacperc/Stijn/Revision/Data/turn_data.dta"

keep icdi mancode1 year month

*Merging mutual fund data from CRSP (icdi, fundno, date, year, month, yearm, expenses, turnover, tnam, date_inc, load, retm)
sort icdi year month
merge icdi year month using "/Users/mkacperc/Stijn/Revision/Data/returns2.dta",nokeep
tab _merge
drop _merge

*Merging recession data (Monthly data based on NBER recession dates from www.nber.org: date, recession2)
sort date
merge date using "/Users/mkacperc/Stijn/Revision/Data/recession_data.dta",nokeep
tab _merge
drop _merge

gen retmktfund=retm-mkt

*Winsorizing fund controls
winsor flow,gen(Wflow) p(0.005)
winsor turnover,gen(Wturn) p(0.005)
winsor retmktfund,gen(Wretmktfund) p(0.005)

*Calculating log of size and age
gen log_assets=ln(tnam)
gen logage=ln(date-date_inc+1)

*Demeaning the series for interpretation reasons

gen sum=logage+log_assets+expenses+Wturn+Wflow+load+siz+val+mom

egen meanage=mean(logage) if sum~=.
egen meanasset=mean(log_assets) if sum~=.
egen meanexp=mean(expenses) if sum~=.
egen meanturn=mean(Wturn) if sum~=.
egen meanflow=mean(Wflow) if sum~=.
egen meanload=mean(load) if sum~=.
egen meanval=mean(val) if sum~=.
egen meansiz=mean(siz) if sum~=.
egen meanmom=mean(mom) if sum~=.

replace logage=logage-meanage
replace log_assets=log_assets-meanasset
replace expenses=expenses-meanexp
replace Wturn=Wturn-meanturn
replace Wflow=Wflow-meanflow
replace load=load-meanload
replace val=val-meanval
replace siz=siz-meansiz
replace mom=mom-meanmom

sort date
by date: egen meanretmkt=mean(Wretmktfund)
gen stdretmkt=abs(Wretmktfund-meanretmkt)
replace stdretmkt=stdretmkt*100

reg stdretmkt recession2 logage log_assets expenses Wturn Wflow load val siz mom, cluster(icdi)
outreg2 using "/Users/mkacperc/Stijn/Revision/ECTA/tableS8.xls", append se bdec(3)
areg stdretmkt recession2 logage log_assets expenses Wturn Wflow load val siz mom,absorb(mancode1) cluster(icdi)
outreg2 using "/Users/mkacperc/Stijn/Revision/ECTA/tableS8.xls", append se bdec(3)

***************************************************
*Performance results (manager level fixed effects)*
***************************************************

clear all

*Loading mutual fund data from CRSP at the manager level (hand constructed mapping between managers and funds in CRSP appended by individual web searches)
*Unit of observation mancode1 year month

use "/Users/mkacperc/Stijn/Revision/Data/turn_data.dta"

keep icdi mancode1 year month

*Merging mutual fund data from CRSP (icdi, fundno, date, year, month, yearm, expenses, turnover, tnam, date_inc, load, retm)
sort icdi year month
merge icdi year month using "/Users/mkacperc/Stijn/Revision/Data/returns2.dta",nokeep
tab _merge
drop _merge

*Merging recession data (Monthly data based on NBER recession dates from www.nber.org: date, recession2)
sort date
merge date using "/Users/mkacperc/Stijn/Revision/Data/recession_data.dta",nokeep
tab _merge
drop _merge

*Merging fund alphas (the input file is based on Matlab file alphafund_new.m)
sort id time
merge id time using "/Users/mkacperc/Stijn/Revision/Data/fundalphas.dta",nokeep
drop _merge

*Winsorizing fund controls
winsor flow,gen(Wflow) p(0.005)
winsor turnover,gen(Wturn) p(0.005)
winsor fundcaralpha,gen(Wfundcaralpha) p(0.025)

*Calculating log of size and age
gen log_assets=ln(tnam)
gen logage=ln(date-date_inc+1)

*Demeaning the series for interpretation reasons

gen sum=logage+log_assets+expenses+Wturn+Wflow+load+siz+val+mom+fundcapmalpha

egen meanage=mean(logage) if sum~=.
egen meanasset=mean(log_assets) if sum~=.
egen meanexp=mean(expenses) if sum~=.
egen meanturn=mean(Wturn) if sum~=.
egen meanflow=mean(Wflow) if sum~=.
egen meanload=mean(load) if sum~=.
egen meanval=mean(val) if sum~=.
egen meansiz=mean(siz) if sum~=.
egen meanmom=mean(mom) if sum~=.

replace logage=logage-meanage
replace log_assets=log_assets-meanasset
replace expenses=expenses-meanexp
replace Wturn=Wturn-meanturn
replace Wflow=Wflow-meanflow
replace load=load-meanload
replace val=val-meanval
replace siz=siz-meansiz
replace mom=mom-meanmom

replace Wfundcaralpha=Wfundcaralpha*100

reg Wfundcaralpha recession2 logage log_assets expenses Wturn Wflow load siz val mom, cluster(date)
outreg2 using "/Users/mkacperc/Stijn/Revision/ECTA/tableS8.xls", append se bdec(3)
areg Wfundcaralpha recession2 logage log_assets expenses Wturn Wflow load siz val mom,absorb(mancode1) cluster(date)
outreg2 using "/Users/mkacperc/Stijn/Revision/ECTA/tableS8.xls", append se bdec(3)
