function RESULTS = RTMFAA_res(PARAMS, PARAMS_fix, PARAMS_sim)



%%%%%%%%%%%% Preliminaries


% primitives that have been calibrated
w0          = PARAMS(1);
rho_vec     = [PARAMS(2) PARAMS(3)];
b1          = PARAMS(4);
b2          = PARAMS(5);
s1          = PARAMS(6); % variance of stock 1 specific shock, z_1
s2          = PARAMS(6);
sa_vec      = [PARAMS(7) PARAMS(8)];
vx          = PARAMS(9);
truncate    = PARAMS(10);
mu          = PARAMS(11)*[1 1 1]'; % mean asset payoffs 
ex_a        = PARAMS(12);
k           = PARAMS(13); % Attention capacity

% primitives that are fixed
ex_12       = PARAMS_fix(1);
r           = PARAMS_fix(2); % gross riskfree rate
informed    = PARAMS_fix(3); % this is the fraction of managers who have capacity

% functions of primitives
Gam         = [1,0,b1;0,1,b2;0,0,1]; % maps risk factor payoffs into asset 
                                     % payoffs: f = mu + Gamma*z
Gam_inv     = inv(Gam);
ex          = [ex_12; ex_12; ex_a]; % expected risk supply

% parameters for simulation
funds       = PARAMS_sim(1); % number of funds for the simulation
funds_inf   = PARAMS_sim(2); % number of informed funds
funds_un    = PARAMS_sim(3); % number of uninformed funds
draws       = PARAMS_sim(4); % number of 'periods'
lastinf     = PARAMS_sim(5); % index of the last informed fund



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%% START MAJOR LOOP %%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



% loop over parameter vectors, solving the the attention allocation and
% computing results for the model on each loop.

for boom = 1:2, % 1 is boom, 2 is recession
  
% set parameter values
rho         = rho_vec(boom);
sa          = sa_vec(boom);  % variance of aggregate shock
sigmas      = [s1 s2 sa]; % vector of variances of z shocks

% preliminaries
Sig_inv     = diag(sigmas.^(-1));



%%%%%%%%%%%% Compute optimal attention allocation



% Set initial values of the K's. Start with all attention allocated to the 
% aggregate risk.
K_vec       = [0; 0; k]; % [K1; K2; Ka] 

% solve for lambdas
Sig_eta_inv     = diag(K_vec);
Sig_bar_eta_inv = informed.*Sig_eta_inv;
Sig_p_inv       = ( ( Sig_bar_eta_inv ).^2 )./( (rho.^2).*vx );
Sigh_j_inv_inf  = Sig_inv + Sig_p_inv + Sig_eta_inv;
Sigh_j_inv_un   = Sig_inv + Sig_p_inv;
Sig_bar         = inv( informed.*Sigh_j_inv_inf + ...
                                           (1 - informed).*Sigh_j_inv_un );
lambdas     = nan(3,1);
for i=1:3
    lambdas(i)  = Sig_bar(i,i)*( 1 + ( (rho^2)*vx ...
                  + informed*K_vec(i))*Sig_bar(i,i) ) ...
                  + (rho^2)*(ex(i)^2)*(Sig_bar(i,i)^2);
end


% If it is not an eq'm to allocate all attention to the aggregate risk then
% slowly allocate attention to risks 1 and 2 until we find the eq'm 

inc             = 0.01; % size of increment for attention adjustments

while (lambdas(3)<max(lambdas(1:2))) && (K_vec(3)>0)
    
    % reallocate attention from the risk with the lowest lambda to the risk
    % with the highest lambda
    [~,i_max]       = max(lambdas);
    if K_vec(3)>=inc
        K_vec(3)        = K_vec(3) - inc;
        K_vec(i_max)    = K_vec(i_max) + inc;
    else
        K_vec(i_max)    = K_vec(i_max) + K_vec(3);
        K_vec(3)        = 0; 
    end
    
    % recompute the lambdas
    Sig_eta_inv     = diag(K_vec);
    Sig_bar_eta_inv = informed.*Sig_eta_inv;
    Sig_p_inv       = ( ( Sig_bar_eta_inv ).^2 )./( (rho.^2).*vx );
    Sigh_j_inv_inf  = Sig_inv + Sig_p_inv + Sig_eta_inv;
    Sigh_j_inv_un   = Sig_inv + Sig_p_inv;
    Sig_bar         = inv( informed.*Sigh_j_inv_inf + ...
                                           (1 - informed).*Sigh_j_inv_un );
    for i=1:3
        lambdas(i)  = Sig_bar(i,i)*( 1 + ( (rho^2)*vx ...
                      + informed*K_vec(i))*Sig_bar(i,i) ) ...
                      + (rho^2)*(ex(i)^2)*(Sig_bar(i,i)^2);
    end

end
K1      = K_vec(1);
K2      = K_vec(2);
Ka      = K_vec(3);


Sig_inv ;
Sig_p_inv ;
Sig_eta_inv;

%%%%%%%%%%%% Generate payoffs, supply shocks and signals



% draw random numbers for asset payoff shocks, signal shocks and asset 
% supply shocks
stream1     = RandStream('mt19937ar','Seed',50001); 
RandStream.setGlobalStream(stream1);
RR1         = randn(draws,3); % asset payoff shocks
stream2     = RandStream('mt19937ar','Seed',50002); 
RandStream.setGlobalStream(stream2);
RR2         = randn(draws,3,funds); % signal shocks
stream3     = RandStream('mt19937ar','Seed',50003); 
RandStream.setGlobalStream(stream3);
RR3         = randn(draws,3); % asset supply shocks 

% construct asset payoffs 
shocks      = repmat(sqrt(sigmas), draws, 1).*RR1; % z's (draws x 3)
payoff      = ones(draws,1)*mu' + shocks*(Gam'); % f's (draws x 3)

% construct supply shocks
supplyshocks = sqrt(vx).*RR3; % x's; supply shocks to the risk factors

% construct private signals on risk factors
sig_sd      = zeros(3,1); 
for i=1:3
    if K_vec(i)~=0
        sig_sd(i) = sqrt(K_vec(i).^(-1));
    end
end
signals     = repmat(shocks, [1 1 funds]) ...
              + repmat(sig_sd', [draws 1 funds]).*RR2; % \eta_j's 
                                                       %(draws x 3 x funds)

% preliminaries for constructing price signals
Sig_eta_inv = diag(K_vec);
Sig_bar_eta_inv = informed.*Sig_eta_inv;
Sig_p_inv   = ( ( Sig_bar_eta_inv ).^2 )./( (rho.^2).*vx );
Sigh_j_inv_inf = Sig_inv + Sig_p_inv + Sig_eta_inv;
Sigh_j_inf  = inv(Sigh_j_inv_inf);
Sigh_j_inv_un = Sig_inv + Sig_p_inv;
Sigh_j_un   = inv(Sigh_j_inv_un); 
Sig_bar     = inv(informed.*Sigh_j_inv_inf + (1-informed).*Sigh_j_inv_un);
B           = eye(3) - Sig_bar*Sig_inv; 
C           = -rho.*Sig_bar*( eye(3) ...
              + ( 1./((rho.^2).*vx ) ).*(Sig_bar_eta_inv') ); 

% Construct price signals: \eta_p = z + B^{-1}*C*x. If B is singular then 
% you need to construct price signals risk by risk. B is diagonal, so it is 
% singular iff a diagonal element equals zero. If B is singular then 
% price signals are set to 0 for prices which contain no information.    
ind_B       = (diag(B)==0); % indicator vector for whether any diagonal 
                            % elements of B are 0 (so B is not invertible)
if sum(ind_B)==0 % B is invertible

    p_signals   = shocks + supplyshocks*((B\C)');

else % B is not invertible

    p_signals = zeros(draws,3);
    if ind_B(1)==0
        p_signals(:,1) = shocks(:,1) + (C(1,1)./B(1,1)).*supplyshocks(:,1); 
    end
    if ind_B(2)==0
        p_signals(:,2) = shocks(:,2) + (C(2,2)./B(2,2)).*supplyshocks(:,2);
    end
    if ind_B(3)==0
        p_signals(:,3) = shocks(:,3) + (C(3,3)./B(3,3)).*supplyshocks(:,3);
    end
    
end



%%%%%%%%%%%% Compute prices and portfolios



% solve for prices
A           = Gam_inv*mu - rho.*Sig_bar*ex;
p_tilde     = (1./r).*(repmat(A',draws,1) + shocks*B' + supplyshocks*C'); 
                                                              % (draws x 1)
p           = p_tilde*Gam';
if  sum(p<0.01)>0,
    disp('The number of negative price realizations is');
    sum(p<0.01)
end

% solve for posterior beliefs and portfolios

q_j         = nan(draws,3,funds); 

for j=1:funds % loop over funds

    if j<=funds_inf %informed fund
        z_hat_j     = ( signals(:,:,j)*Sig_eta_inv' ...
                                    + p_signals*Sig_p_inv' )*(Sigh_j_inf');
        Ej_f_tilde  = repmat(mu'*Gam_inv', draws, 1) + z_hat_j;
        q_tilde_j   = (1./rho).*(Ej_f_tilde - r.*p_tilde)*(Sigh_j_inv_inf');
        q_j(:,:,j)  = q_tilde_j*Gam_inv;
    else % uninformed fund
        z_hat_j     = ( p_signals*Sig_p_inv' )*(Sigh_j_un');
        Ej_f_tilde  = repmat(mu'*Gam_inv', draws, 1) + z_hat_j;
        q_tilde_j   = (1./rho).*(Ej_f_tilde - r.*p_tilde)*(Sigh_j_inv_un');
        q_j(:,:,j)  = q_tilde_j*Gam_inv;
    end
        
end

% format matrices so that they're compatible with the code that was
% inherited for computing results
q               = nan(draws,funds,3);
for i=1:funds
    q(:,i,:)    = q_j(:,:,i);
end                              


                               
%%%%%%%%%%%% Compute results



% asset supply and average asset supply
asset_supply    = ( ones(draws,1)*ex' + supplyshocks )*Gam_inv;
asset_sup_av    = Gam_inv'*ex; % average asset supply

% value weights for market portfolio (excluding rf asset)
vwm         =  ( p.*asset_supply )./( sum(p.*asset_supply, 2)*ones(1,3) );

% return of risky assets    
real_return = payoff./p -1;  % (draws x 3)

% return on the market portfolio (excluding rf asset)
mkt_return  = sum((vwm.*real_return)')';  %(draws x 1)

% fund value weights including rf asset (draws x funds x 4)
vw          = repmat(reshape(p,[draws 1 3]),[1 funds 1]).*q/w0;
vw(:,:,4)   = 1-sum(vw(:,:,1:3),3);

% fund value weights excluding the rf asset (draws x funds x 3)
vw_wo       = vw(:,:,1:3)./repmat(sum(vw(:,:,1:3),3),[1 1 3]);

% compute the return of each fund: the sum of value-weighted returns on 
% each asset, including the riskfree 
allreturns          = repmat(reshape(real_return,[draws 1 3]),[1 funds 1]);
allreturns(:,:,4)   = (r-1)*ones(draws,funds);
fund_return         = sum(vw.*allreturns,3); % (draws x funds)

% compute the abnormal return of each fund: its return minus the return on
% the market portfolio of risky assets
fund_ab_ret         = fund_return - mkt_return*ones(1,funds);

% compute the deviation of the excess payoff of each fund in each period 
% from the mean excess payoff of funds: q_j'*(f - p*r) - \bar{q}'*(f - p*r)
pay_ex      = sum( q.*repmat( reshape(payoff - p.*r, [draws,1,3]), ...
                                                          [1,funds,1]), 3);
pay_ex_dev  = pay_ex - mean(pay_ex,2)*ones(1,funds); % (draws x funds)  
    
% Adjust matrices for the recession state: repeat low realizations of 
% the market return so that the average market return is lower in 
% recessions than in booms and make the necessary changes to other matrices
if boom==2,
    [mktsort, mktind] = sort(mkt_return);
    mkt_return      = [mkt_return; mktsort(1:round(draws*truncate))];
    fundsort        = fund_return(mktind,:);
    fund_return     = [fund_return; fundsort(1:round(draws*truncate),:)];
    realsort        = real_return(mktind,:);
    real_return     = [real_return; realsort(1:round(draws*truncate),:)];
    fund_ab_sort    = fund_ab_ret(mktind,:);
    fund_ab_ret     = [fund_ab_ret; ...
                                  fund_ab_sort(1:round(draws*truncate),:)];
    pay_ex_dev_sort = pay_ex_dev(mktind,:); 
    pay_ex_dev      = [pay_ex_dev; ...
                               pay_ex_dev_sort(1:round(draws*truncate),:)]; 
end

% compute results for booms and recessions

if boom ==1, % boom results
    
    b_prec_siga = Ka;
    b_prec_sig1 = K1;
    b_meanret   = mean(real_return);
    b_mktret    = mean(mkt_return);
    b_stdmkt    = std(mkt_return);
    b_leverage  = mean(mean(vw(:,:,4))); % average value weight on the rf 
                                         % asset (scalar)
        
    % call up other programs to compute summary stats
    fund_stats0414;
    asset_stats0414;
    infomoments0514;
    itable = nan(4,6);
    itable(:,4:6) = moments;

else % recession results
    
    r_prec_siga = Ka;
    r_prec_sig1 = K1;
    r_meanret   = mean(real_return);
    r_mktret    = mean(mkt_return);
    r_stdmkt    = std(mkt_return);    
    r_leverage  = mean(mean(vw(:,:,4)));

    % call up other programs to compute summary stats
    fund_stats0414;
    asset_stats0414;
    infomoments0514;
    itable(:,1:3) = moments;

end


end % end boom/recession loop



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%% END MAJOR LOOPS %%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



%%%%%%%%%% Organize results for output of function



% attention allocation
RESULTS.aa  = { -999 'R' 'E'; ...
                'K1' r_prec_sig1 b_prec_sig1; ...
                'Ka' r_prec_siga b_prec_siga };

% results for the calibration moments
RESULTS.cm  = { -999 'R' 'E'; ...
                'Mkt return %' r_mktret.*100 b_mktret.*100; ...
                'Std mkt ret %' r_stdmkt.*100 b_stdmkt.*100; ...
                'Rf holding %' r_leverage.*100 b_leverage.*100; ...
                'Std ret a1 & a2 %' asset_table(3,1) asset_table(3,2); ...
                'Avg beta a1 & a2' asset_table(7,1) asset_table(7,2); ...
                'Std beta a1 & a2' asset_table(8,1) asset_table(8,2) };

% table reported in supplementary appendix
RESULTS.t1  = itable;
RESULTS.t2  = fund_table([1:6,9],:);

% results for Propositions 4 and 6
RESULTS.p4  = fund_table(7,:);
RESULTS.p6  = fund_table(8,:); 



end % end function 