% This code produces results for funds

% Produce fund cutoff numbers for three groups of funds: all funds; 
% informed funds and uninformed funds. Non-fund investors -- the last 20%
% of the investors in the simulation -- are not used for these
% calculuations.
cutofflo    = [1, 1, lastinf+1];
cutoffhi    = [funds*0.8, lastinf, funds*0.8];

% Do 1 regression for all uninformed firms (same portfolios)
f           = funds*0.8; % take the last uninformed fund as the 
                         % representative uninformed fund     
results     = ols(fund_return(:,f)-(r-1),...
                           [ones(length(mkt_return),1), mkt_return-(r-1)]);
frsq        = results.rsqr*ones(1,funds);
falphas     = results.beta(1)*ones(1,funds);
fbetas      = results.beta(2)*ones(1,funds);
fidiovol    = results.sige^(1/2)*ones(1,funds);

% Do regressions for each informed fund
for f = 1:lastinf,
    results         = ols(fund_return(:,f)-(r-1),...
                           [ones(length(mkt_return),1), mkt_return-(r-1)]);
    frsq(1,f)       = results.rsqr;
    falphas(1,f)    = results.beta(1);
    fbetas(1,f)     = results.beta(2);
    fidiovol(1,f)   = results.sige^(1/2);
end

% Compute results for each of the three groups
for group = 1:3,
    % group 1 is all the funds (first 80% of investors)
    % group 2 is the informed funds
    % group 3 is the uninformed funds 
    
    ng      = -cutofflo(group)+cutoffhi(group)+1; % size of group
    vw_wo_g = vw_wo(:,cutofflo(group):cutoffhi(group),:); % value weights
    vw_g    = vw(:,cutofflo(group):cutoffhi(group),:);
    
    
    if boom==1, % results for boom
        
        % portfolio dispersion
        vw_dev = vw_wo_g - repmat(reshape(vwm, [draws 1 3]), [1 ng 1]);
            % deviation of fund value weight in the risky assets from the
            % market value weights (draws x funds x 3)
        b_portdisp(1,group) = mean( mean( sum( vw_dev.^2, 3 ) ) ); 
        
        b_concentrate(1,group) = sum(mean(var(vw_g,0,2),1),3);

        
        % dispersion in abnormal returns
        b_abretdisp(1,group) = mean( mean( abs( fund_ab_ret(:,cutofflo(group):cutoffhi(group)) - mean(fund_ab_ret(:,1:funds*0.8),2)*ones(1,ng) ) ) );
        
        % Dispersion in alphas
        b_alphadisp(1, group) = mean( abs( falphas(cutofflo(group):cutoffhi(group)) - mean(falphas(1:funds*0.8)) ) );
        
        % Dispersion in betas
        b_betadisp(1, group) = mean( abs( fbetas(cutofflo(group):cutoffhi(group)) - mean(fbetas(1:funds*0.8)) ) );

        % performance measures
        b_avabret(1, group) = mean(mean( fund_ab_ret(:,cutofflo(group):cutoffhi(group)) ) );
        b_avalpha(1, group) = mean( falphas(cutofflo(group):cutoffhi(group)) );
        
        % Prop 4: dispersion of portfolio excess returns
        b_paydisp(1,group)  = mean( mean( pay_ex_dev(:,cutofflo(group):cutoffhi(group)).^2 ) );
        
        % Prop 6: portfolio excess return
        b_exret(1,group)    = mean( mean( pay_ex_dev(:,cutofflo(group):cutoffhi(group)) ) );

    else % results for recession
        
        % portfolio dispersion - note that we need to make an adjustment to
        % account for the repetition of observations for which the market
        % return is low
        sum_vw_dev_sq = sum( ( vw_wo_g - repmat(reshape(vwm, [draws 1 3]), [1 ng 1]) ).^2, 3);
        sum_vw_dev_sq_sort = sum_vw_dev_sq(mktind,:);
        sum_vw_dev_sq = [sum_vw_dev_sq; ...
                            sum_vw_dev_sq_sort(1:round(draws*truncate),:)];
        r_portdisp(1,group) = mean( mean( sum_vw_dev_sq ) ); 

        r_concentrate(1,group) = sum(mean(var(vw_g,0,2),1),3);

        % dispersion in abnormal returns
        r_abretdisp(1,group) = mean( mean( abs( fund_ab_ret(:,cutofflo(group):cutoffhi(group)) - mean(fund_ab_ret(:,1:funds*0.8),2)*ones(1,ng) ) ) );
        
        % Dispersion in alphas
        r_alphadisp(1, group) = mean( abs( falphas(cutofflo(group):cutoffhi(group)) - mean(falphas(1:funds*0.8)) ) );
        
        % Dispersion in betas
        r_betadisp(1, group) = mean( abs( fbetas(cutofflo(group):cutoffhi(group)) - mean(fbetas(1:funds*0.8)) ) );

        % performance measures
        r_avabret(1, group) = mean(mean( fund_ab_ret(:,cutofflo(group):cutoffhi(group)) ) );
        
        r_avalpha(1, group) = mean( falphas(cutofflo(group):cutoffhi(group)) );
        
        % Prop 4: dispersion of portfolio excess returns
        r_paydisp(1,group)  = mean( mean( pay_ex_dev(:,cutofflo(group):cutoffhi(group)).^2 ) );
        
        % Prop 6: portfolio excess return 
        r_exret(1,group)    = mean( mean( pay_ex_dev(:,cutofflo(group):cutoffhi(group)) ) );
          

    end
end

if boom==2,
    fund_table(1,:) = [r_portdisp b_portdisp];
    fund_table(2,:) = [r_abretdisp b_abretdisp].*100;
    fund_table(3,:) = [r_alphadisp b_alphadisp].*100;
    fund_table(4,:) = [r_betadisp b_betadisp];
    fund_table(5,:) = [r_avabret b_avabret].*100;
    fund_table(6,:) = [r_avalpha b_avalpha].*100;
    fund_table(7,:) = [r_paydisp b_paydisp];
    fund_table(8,:) = [r_exret b_exret];
    fund_table(9,:) = [r_concentrate b_concentrate];
end